@@ -4,9 +4,9 @@ use warnings;
 
 package Git::Wrapper;
 #ABSTRACT: Wrap git(7) command-line interface
-$Git::Wrapper::VERSION = '0.045_090'; # TRIAL
+$Git::Wrapper::VERSION = '0.045_091'; # TRIAL
 
-$Git::Wrapper::VERSION = '0.045090';our $DEBUG=0;
+$Git::Wrapper::VERSION = '0.045091';our $DEBUG=0;
 
 # Prevent ANSI color with extreme prejudice
 # https://github.com/genehack/Git-Wrapper/issues/13
@@ -223,9 +223,12 @@ sub log {
     if ($raw) {
       my @modifications;
 
-      # example output:
+      # example outputs:
+      #  regular:
       # :000000 100644 0000000000000000000000000000000000000000 ce013625030ba8dba906f756967f9e9ca394464a A     foo/bar
-      while(@out and $out[0] =~ m/^\:(\d{6}) (\d{6}) (\w{40}) (\w{40}) (\w{1})\t(.*)$/) {
+      #  with score value after file type (see https://github.com/genehack/Git-Wrapper/issues/70):
+      # :100644 100644 c659037... c659037... R100       foo bar
+      while(@out and $out[0] =~ m/^\:(\d{6}) (\d{6}) (\w{40}) (\w{40}) (\w{1}[0-9]*)\t(.*)$/) {
         push @modifications, Git::Wrapper::File::RawModification->new($6,$5,$1,$2,$3,$4);
         shift @out;
       }
@@ -413,7 +416,7 @@ Git::Wrapper - Wrap git(7) command-line interface
 
 =head1 VERSION
 
-version 0.045_090
+version 0.045_091
 
 =head1 SYNOPSIS
 
